@@ -54,6 +54,7 @@ FORWARDED_BLOB_PROPERTIES = [
     "tags",
     "tag_count",
 ]
+_ROOT_PATH = "/"
 
 
 class AzureDatalakeFileSystem(AbstractFileSystem):
@@ -720,7 +721,7 @@ class AzureBlobFileSystem(AsyncFileSystem):
         if invalidate_cache:
             self.dircache.clear()
         if (container in ["", ".", "*", delimiter]) and (path in ["", delimiter]):
-            if path not in self.dircache or invalidate_cache or return_glob:
+            if _ROOT_PATH not in self.dircache or invalidate_cache or return_glob:
                 # This is the case where only the containers are being returned
                 logger.info(
                     "Returning a list of containers in the azure blob storage account"
@@ -728,9 +729,9 @@ class AzureBlobFileSystem(AsyncFileSystem):
                 contents = self.service_client.list_containers(include_metadata=True)
                 containers = [c async for c in contents]
                 files = await self._details(containers)
-                self.dircache[path] = files
+                self.dircache[_ROOT_PATH] = files
 
-            return self.dircache[path]
+            return self.dircache[_ROOT_PATH]
         else:
             if target_path not in self.dircache or invalidate_cache or return_glob:
                 if container not in ["", delimiter]:
@@ -1037,6 +1038,17 @@ class AzureBlobFileSystem(AsyncFileSystem):
             ):
                 yield path, dirs, files
 
+    async def _container_exists(self, container_name):
+        try:
+            async with self.service_client.get_container_client(
+                container_name
+            ) as client:
+                await client.get_container_properties()
+        except ResourceNotFoundError:
+            return False
+        else:
+            return True
+
     async def _mkdir(self, path, create_parents=True, delimiter="/", **kwargs):
         """
         Mkdir is a no-op for creating anything except top-level containers.
@@ -1056,47 +1068,21 @@ class AzureBlobFileSystem(AsyncFileSystem):
         """
         fullpath = path
         container_name, path = self.split_path(path, delimiter=delimiter)
-        _containers = await self._ls("")
-        _containers = [c["name"] for c in _containers]
-        # The list of containers will be returned from _ls() in a directory format
-        # Need a placeholder that presents the container_name in a directory format
-        if _containers is None:
-            _containers = []
-        try:
-            if container_name not in _containers:
-                if create_parents:
-                    # create new container
-                    await self.service_client.create_container(
-                        name=container_name, metadata={"is_directory": "true"}
-                    )
-                    self.invalidate_cache(self._parent(container_name))
-                else:
-                    raise PermissionError(
-                        "Azure Container does not exist.  Set create_parents=True to create!!"
-                    )
-            else:
-                exist_ok = kwargs.get("exist_ok", True)
-                if exist_ok:
-                    pass
-                else:
-                    raise
-
-        except PermissionError:
+        container_exists = await self._container_exists(container_name)
+        if not create_parents and not container_exists:
             raise PermissionError(
-                f"Unable to create Azure container {container_name} with \
-                create_parents=False"
+                "Azure Container does not exist.  Set create_parents=True to create!!"
             )
 
-        except Exception as e:
-            # everything else
-            exist_ok = kwargs.get("exist_ok", True)
-            if exist_ok:
-                pass
-            else:
-                raise FileExistsError(
-                    f"Cannot overwrite existing Azure container -- {container_name} already exists. \
-                        with Azure error {e}"
-                )
+        if container_exists and not kwargs.get("exist_ok", True):
+            raise FileExistsError(
+                f"Cannot overwrite existing Azure container -- {container_name} already exists."
+            )
+
+        if not container_exists:
+            await self.service_client.create_container(container_name)
+            self.invalidate_cache(_ROOT_PATH)
+
         self.invalidate_cache(self._parent(fullpath))
 
     mkdir = sync_wrapper(_mkdir)
@@ -1201,12 +1187,10 @@ class AzureBlobFileSystem(AsyncFileSystem):
         """
 
         container_name, path = self.split_path(path, delimiter=delimiter)
-        _containers = await self._ls("")
-        _containers = [c["name"] for c in _containers]
-        if (container_name in _containers) and (not path):
-            # delete container
+        container_exists = await self._container_exists(container_name)
+        if container_exists and not path:
             await self.service_client.delete_container(container_name)
-            self.invalidate_cache(self._parent(path))
+            self.invalidate_cache(_ROOT_PATH)
 
     def size(self, path):
         return sync(self.loop, self._size, path)
@@ -1271,8 +1255,11 @@ class AzureBlobFileSystem(AsyncFileSystem):
         container_name, path = self.split_path(path)
 
         if not path:
-            # Empty paths exist by definition
-            return True
+            if container_name:
+                return await self._container_exists(container_name)
+            else:
+                # Empty paths exist by definition
+                return True
 
         async with self.service_client.get_blob_client(container_name, path) as bc:
             exists = await bc.exists()
